<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litematrimony\Profile\Interfaces\VisitRepositoryInterface;

class VisitPublicController extends BaseController
{
    // use VisitWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litematrimony\Visit\Interfaces\VisitRepositoryInterface $visit
     *
     * @return type
     */
    public function __construct(VisitRepositoryInterface $visit)
    {
        $this->repository = $visit;
        parent::__construct();
    }

    /**
     * Show visit's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $visits = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$profile::$visit.names'))
            ->view('$profile::public.visit.index')
            ->data(compact('$visits'))
            ->output();
    }

    /**
     * Show visit's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $visits = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$profile::$visit.names'))
            ->view('$profile::public.visit.index')
            ->data(compact('$visits'))
            ->output();
    }

    /**
     * Show visit.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $visit = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$visit->name . trans('$profile::$visit.name'))
            ->view('$profile::public.visit.show')
            ->data(compact('$visit'))
            ->output();
    }

}
