<?php

namespace Litematrimony\Profile\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litematrimony\Profile\Models\Request;

class RequestPolicy
{

    /**
     * Determine if the given user can view the request.
     *
     * @param UserPolicy $user
     * @param Request $request
     *
     * @return bool
     */
    public function view(UserPolicy $user, Request $request)
    {
        if ($user->canDo('profile.request.view') && $user->isAdmin()) {
            return true;
        }

        return $request->user_id == user_id() && $request->user_type == user_type();
    }

    /**
     * Determine if the given user can create a request.
     *
     * @param UserPolicy $user
     * @param Request $request
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('profile.request.create');
    }

    /**
     * Determine if the given user can update the given request.
     *
     * @param UserPolicy $user
     * @param Request $request
     *
     * @return bool
     */
    public function update(UserPolicy $user, Request $request)
    {
        if ($user->canDo('profile.request.edit') && $user->isAdmin()) {
            return true;
        }

        return $request->user_id == user_id() && $request->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given request.
     *
     * @param UserPolicy $user
     * @param Request $request
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Request $request)
    {
        return $request->user_id == user_id() && $request->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given request.
     *
     * @param UserPolicy $user
     * @param Request $request
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Request $request)
    {
        if ($user->canDo('profile.request.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given request.
     *
     * @param UserPolicy $user
     * @param Request $request
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Request $request)
    {
        if ($user->canDo('profile.request.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
