<?php

namespace Litematrimony\Profile\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litematrimony\Profile\Models\Shortlist;

class ShortlistPolicy
{

    /**
     * Determine if the given user can view the shortlist.
     *
     * @param UserPolicy $user
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function view(UserPolicy $user, Shortlist $shortlist)
    {
        if ($user->canDo('profile.shortlist.view') && $user->isAdmin()) {
            return true;
        }

        return $shortlist->user_id == user_id() && $shortlist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shortlist.
     *
     * @param UserPolicy $user
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('profile.shortlist.create');
    }

    /**
     * Determine if the given user can update the given shortlist.
     *
     * @param UserPolicy $user
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function update(UserPolicy $user, Shortlist $shortlist)
    {
        if ($user->canDo('profile.shortlist.edit') && $user->isAdmin()) {
            return true;
        }

        return $shortlist->user_id == user_id() && $shortlist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shortlist.
     *
     * @param UserPolicy $user
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Shortlist $shortlist)
    {
        return $shortlist->user_id == user_id() && $shortlist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shortlist.
     *
     * @param UserPolicy $user
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Shortlist $shortlist)
    {
        if ($user->canDo('profile.shortlist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shortlist.
     *
     * @param UserPolicy $user
     * @param Shortlist $shortlist
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Shortlist $shortlist)
    {
        if ($user->canDo('profile.shortlist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
